
class DiagnosticLabel:
    PRERUN_DIAGNOSTIC = "prerun-diagnostic"
    POSTRUN_DIAGNOSTIC = "postrun-diagnostic"

class RuntimeConfigPaths:
    DIAGNOSTIC_PRERUN = "/configuration/diagnostics/prerun-diagnostic"
    DIAGNOSTIC_POSTRUN = "/configuration/diagnostics/postrun-diagnostic"
